require 'spec_helper'

describe AndroidDrawableResizer do

  describe 'directory_for_density' do
    
    it 'returns proper directory name' do
      result = directory_for_density(:xxhdpi)
      expect(result).to eq('drawable-xxhdpi')
    end

  end

  describe 'execution_dir' do

    context 'when invalid directory passed' do
      it 'returns nil' do
        result = execution_dir('aaa')
        expect(result).to eq(nil)
      end
    end

    context 'when no directory is passed' do
      context 'when execution directory is not /res' do
        it 'returns nil' do
          expect(execution_dir).to eq(nil)
        end
      end

      context 'when execution directory is /res' do
        it 'returns \'.\' directory' do
          Dir.chdir('spec/assets/res') do
            expect(execution_dir).to eq('.')
          end
        end
      end
    end

    context 'when directory is passed' do
      context 'when passed directory is not /res' do
        it 'returns nil' do
          expect(execution_dir('spec/assets/res_empty')).to eq(nil)
        end
      end

      context 'when passed directory is not valid' do
        it 'returns nil' do
          expect(execution_dir('asdf')).to eq(nil)
        end
      end

      context 'when passed directory is valid /res' do
        let(:candidate_dir) { 'spec/assets/res' }

        it 'returns the passed directory' do
          result = execution_dir(candidate_dir)
          expect(result).to eq(candidate_dir)
        end

        context 'when block given' do
          it 'executes block on correct execution dir' do
            block_dir = false
            execution_dir(candidate_dir) { block_dir = Dir.pwd }
            expect(block_dir).to eq("#{Dir.pwd}/#{candidate_dir}")
          end
        end
      end
    end

  end

end
